SWDEV-339657 - Update catch codes with correct coordinates (#2735)
Change-Id: I8ca78d770a742bf6c2abede494759caa923fcc19
[ROCm/hip-tests commit: d31aca651d]
This commit is contained in:
committed by
GitHub
orang tua
246f9b4c6e
melakukan
bebf1a2bc9
@@ -57,7 +57,7 @@ Testcase Scenarios :
|
||||
* Kernel Functions to copy.
|
||||
*/
|
||||
static __global__ void copy_ker_func(int* a, int* b) {
|
||||
int tx = hipBlockIdx_x*hipBlockDim_x + hipThreadIdx_x;
|
||||
int tx = blockIdx.x*blockDim.x + threadIdx.x;
|
||||
if (tx < LEN) b[tx] = a[tx];
|
||||
}
|
||||
|
||||
|
||||
Reference in New Issue
Block a user